@@ -8,13 +8,11 @@ from snakeoil.sequences import split_elements, split_negations
 
 
 class UnhashableComplex(complex):
-
     def __hash__(self):
         raise TypeError
 
 
 class TestStableUnique:
-
     def common_check(self, func):
         # silly
         assert func(()) == []
@@ -23,9 +21,10 @@ class TestStableUnique:
         # neither
 
     def test_stable_unique(self, func=sequences.stable_unique):
-        assert list(set([1, 2, 3])) == [1, 2, 3], \
-            "this test is reliant on the interpreter hasing 1,2,3 into a specific ordering- " \
+        assert list(set([1, 2, 3])) == [1, 2, 3], (
+            "this test is reliant on the interpreter hasing 1,2,3 into a specific ordering- "
             "for whatever reason, ordering differs, thus this test can't verify it"
+        )
         assert func([3, 2, 1]) == [3, 2, 1]
 
     def test_iter_stable_unique(self):
@@ -43,20 +42,19 @@ class TestStableUnique:
         uc = UnhashableComplex
         res = sequences.unstable_unique([uc(1, 0), uc(0, 1), uc(1, 0)])
         # sortable
-        assert sorted(sequences.unstable_unique(
-            [[1, 2], [1, 3], [1, 2], [1, 3]])) == [[1, 2], [1, 3]]
+        assert sorted(sequences.unstable_unique([[1, 2], [1, 3], [1, 2], [1, 3]])) == [
+            [1, 2],
+            [1, 3],
+        ]
         assert res == [uc(1, 0), uc(0, 1)] or res == [uc(0, 1), uc(1, 0)]
         assert sorted(sequences.unstable_unique(self._generator())) == sorted(range(6))
 
 
 class TestChainedLists:
-
     @staticmethod
     def gen_cl():
         return sequences.ChainedLists(
-            list(range(3)),
-            list(range(3, 6)),
-            list(range(6, 100))
+            list(range(3)), list(range(3, 6)), list(range(6, 100))
         )
 
     def test_contains(self):
@@ -72,7 +70,7 @@ class TestChainedLists:
 
     def test_str(self):
         l = sequences.ChainedLists(list(range(3)), list(range(3, 5)))
-        assert str(l) == '[ [0, 1, 2], [3, 4] ]'
+        assert str(l) == "[ [0, 1, 2], [3, 4] ]"
 
     def test_getitem(self):
         cl = self.gen_cl()
@@ -108,15 +106,18 @@ class Test_iflatten_instance:
     def test_it(self):
         o = OrderedDict((k, None) for k in range(10))
         for l, correct, skip in (
-                (["asdf", ["asdf", "asdf"], 1, None],
-                 ["asdf", "asdf", "asdf", 1, None], str),
-                ([o, 1, "fds"], [o, 1, "fds"], (str, OrderedDict)),
-                ([o, 1, "fds"], list(range(10)) + [1, "fds"], str),
-                ("fds", ["fds"], str),
-                ("fds", ["f", "d", "s"], int),
-                ('', [''], str),
-                (1, [1], int),
-                ):
+            (
+                ["asdf", ["asdf", "asdf"], 1, None],
+                ["asdf", "asdf", "asdf", 1, None],
+                str,
+            ),
+            ([o, 1, "fds"], [o, 1, "fds"], (str, OrderedDict)),
+            ([o, 1, "fds"], list(range(10)) + [1, "fds"], str),
+            ("fds", ["fds"], str),
+            ("fds", ["f", "d", "s"], int),
+            ("", [""], str),
+            (1, [1], int),
+        ):
             iterator = self.func(l, skip)
             assert list(iterator) == correct
             assert list(iterator) == []
@@ -126,6 +127,7 @@ class Test_iflatten_instance:
         # have to iterate.
         def fail():
             return list(self.func(None))
+
         with pytest.raises(TypeError):
             fail()
 
@@ -148,13 +150,16 @@ class Test_iflatten_func:
     def test_it(self):
         o = OrderedDict((k, None) for k in range(10))
         for l, correct, skip in (
-                (["asdf", ["asdf", "asdf"], 1, None],
-                 ["asdf", "asdf", "asdf", 1, None], str),
-                ([o, 1, "fds"], [o, 1, "fds"], (str, OrderedDict)),
-                ([o, 1, "fds"], list(range(10)) + [1, "fds"], str),
-                ("fds", ["fds"], str),
-                (1, [1], int),
-                ):
+            (
+                ["asdf", ["asdf", "asdf"], 1, None],
+                ["asdf", "asdf", "asdf", 1, None],
+                str,
+            ),
+            ([o, 1, "fds"], [o, 1, "fds"], (str, OrderedDict)),
+            ([o, 1, "fds"], list(range(10)) + [1, "fds"], str),
+            ("fds", ["fds"], str),
+            (1, [1], int),
+        ):
             iterator = self.func(l, lambda x: isinstance(x, skip))
             assert list(iterator) == correct
             assert list(iterator) == []
@@ -164,6 +169,7 @@ class Test_iflatten_func:
         # have to iterate.
         def fail():
             return list(self.func(None, lambda x: False))
+
         with pytest.raises(TypeError):
             fail()
 
@@ -189,25 +195,24 @@ class Test_predicate_split:
         assert true_l == list(range(0, 100, 2))
 
     def test_key(self):
-        false_l, true_l = self.kls(lambda x: x % 2 == 0,
-                                   ([0, x] for x in range(100)),
-                                   key=itemgetter(1))
+        false_l, true_l = self.kls(
+            lambda x: x % 2 == 0, ([0, x] for x in range(100)), key=itemgetter(1)
+        )
         assert false_l == [[0, x] for x in range(1, 100, 2)]
         assert true_l == [[0, x] for x in range(0, 100, 2)]
 
 
 class TestSplitNegations:
-
     def test_empty(self):
         # empty input
-        seq = ''
+        seq = ""
         assert split_negations(seq) == ((), ())
 
     def test_bad_value(self):
         # no-value negation should raise a ValueError
         bad_values = (
-            '-',
-            'a b c - d f e',
+            "-",
+            "a b c - d f e",
         )
 
         for s in bad_values:
@@ -216,7 +221,7 @@ class TestSplitNegations:
 
     def test_negs(self):
         # all negs
-        seq = ('-' + str(x) for x in range(100))
+        seq = ("-" + str(x) for x in range(100))
         assert split_negations(seq) == (tuple(map(str, range(100))), ())
 
     def test_pos(self):
@@ -226,31 +231,33 @@ class TestSplitNegations:
 
     def test_neg_pos(self):
         # both
-        seq = (('-' + str(x), str(x)) for x in range(100))
+        seq = (("-" + str(x), str(x)) for x in range(100))
         seq = chain.from_iterable(seq)
-        assert split_negations(seq) == (tuple(map(str, range(100))), tuple(map(str, range(100))))
+        assert split_negations(seq) == (
+            tuple(map(str, range(100))),
+            tuple(map(str, range(100))),
+        )
 
     def test_converter(self):
         # converter method
-        seq = (('-' + str(x), str(x)) for x in range(100))
+        seq = (("-" + str(x), str(x)) for x in range(100))
         seq = chain.from_iterable(seq)
         assert split_negations(seq, int) == (tuple(range(100)), tuple(range(100)))
 
 
 class TestSplitElements:
-
     def test_empty(self):
         # empty input
-        seq = ''
+        seq = ""
         assert split_elements(seq) == ((), (), ())
 
     def test_bad_value(self):
         # no-value neg/pos should raise ValueErrors
         bad_values = (
-            '-',
-            '+',
-            'a b c - d f e',
-            'a b c + d f e',
+            "-",
+            "+",
+            "a b c - d f e",
+            "a b c + d f e",
         )
 
         for s in bad_values:
@@ -259,7 +266,7 @@ class TestSplitElements:
 
     def test_negs(self):
         # all negs
-        seq = ('-' + str(x) for x in range(100))
+        seq = ("-" + str(x) for x in range(100))
         assert split_elements(seq) == (tuple(map(str, range(100))), (), ())
 
     def test_neutral(self):
@@ -269,12 +276,12 @@ class TestSplitElements:
 
     def test_pos(self):
         # all pos
-        seq = ('+' + str(x) for x in range(100))
+        seq = ("+" + str(x) for x in range(100))
         assert split_elements(seq) == ((), (), tuple(map(str, range(100))))
 
     def test_neg_pos(self):
         # both negative and positive values
-        seq = (('-' + str(x), '+' + str(x)) for x in range(100))
+        seq = (("-" + str(x), "+" + str(x)) for x in range(100))
         seq = chain.from_iterable(seq)
         assert split_elements(seq) == (
             tuple(map(str, range(100))),
@@ -284,7 +291,7 @@ class TestSplitElements:
 
     def test_neg_neu_pos(self):
         # all three value types
-        seq = (('-' + str(x), str(x), '+' + str(x)) for x in range(100))
+        seq = (("-" + str(x), str(x), "+" + str(x)) for x in range(100))
         seq = chain.from_iterable(seq)
         assert split_elements(seq) == (
             tuple(map(str, range(100))),
@@ -294,7 +301,10 @@ class TestSplitElements:
 
     def test_converter(self):
         # converter method
-        seq = (('-' + str(x), str(x), '+' + str(x)) for x in range(100))
+        seq = (("-" + str(x), str(x), "+" + str(x)) for x in range(100))
         seq = chain.from_iterable(seq)
         assert split_elements(seq, int) == (
-            tuple(range(100)), tuple(range(100)), tuple(range(100)))
+            tuple(range(100)),
+            tuple(range(100)),
+            tuple(range(100)),
+        )
